@@ -2,6 +2,8 @@ import datetime
 
 import htmlgenerator as hg
 from django.conf import settings
+from django.db import models
+from django.db.models import ManyToOneRel
 from django.http import HttpResponse
 from django.template.context import _builtin_context_processors
 from django.utils.formats import localize
@@ -98,6 +100,8 @@ class ObjectFieldLabel(hg.ContextValue):
             return label.fget.__name__.replace("_", " ")
         if callable(label):
             return label.__name__.replace("_", " ")
+        if isinstance(label, ManyToOneRel):
+            return label.name.replace("_", " ").capitalize()
         return label.title() if self.title and isinstance(label, str) else label
 
 
@@ -131,6 +135,8 @@ class ObjectFieldValue(hg.Lazy):
         value = localize(value, use_l10n=settings.USE_L10N)
         if self.formatter:
             value = self.formatter(value)
+        if isinstance(value, models.Manager):
+            value = ", ".join(value.all())
         return value
 
 
